@@ -2,18 +2,14 @@
 """
 import logging
 
-from django_mongoengine import fields
-from mongoengine.queryset.base import CASCADE
+from xml_utils.commons import exceptions
+from xml_utils.xsd_tree.xsd_tree import XSDTree
 
-import xml_utils.commons.exceptions as exceptions
-from core_exporters_app.components.exporter.models import Exporter
 from core_exporters_app.exporters.exporter import (
     AbstractExporter,
     TransformResult,
     TransformResultContent,
 )
-from core_main_app.components.xsl_transformation.models import XslTransformation
-from xml_utils.xsd_tree.xsd_tree import XSDTree
 
 logger = logging.getLogger(__name__)
 
@@ -64,7 +60,7 @@ class XslExporter(AbstractExporter):
         for xml_item in xml_inputs:
             # generate the title document with the sha
             document_name_with_sha = AbstractExporter.get_title_document(
-                xml_item["title"], xml_item["xml_content"]
+                xml_item.title, xml_item.xml_content
             )
             transform_result = TransformResult()
             # set the document name to the collection
@@ -75,7 +71,7 @@ class XslExporter(AbstractExporter):
             transform_result_content = TransformResultContent()
             transform_result_content.file_name = document_name_with_sha
             # sets the content and extension
-            dom = XSDTree.transform_to_xml(xml_item["xml_content"])
+            dom = XSDTree.transform_to_xml(xml_item.xml_content)
             transform_result_content.content_converted = str(self.transformation(dom))
             transform_result_content.content_extension = self.extension
             # add the content to the list of content
@@ -97,46 +93,12 @@ class XslExporter(AbstractExporter):
 
         try:
             extension_result = XSDTree.get_extension(xslt)
-        except exceptions.XMLError as e:
+        except exceptions.XMLError as exception:
             logger.error(
-                "It is not possible to determine the output format, xml by default will be used: {0}".format(
-                    str(e)
-                )
+                "It is not possible to determine the output format, "
+                "xml by default will be used: %s",
+                str(exception),
             )
 
         if extension_result:
             self.extension = ".{!s}".format(extension_result)
-
-
-class ExporterXsl(Exporter):
-    """Export XSL object"""
-
-    xsl_transformation = fields.ReferenceField(
-        XslTransformation, blank=False, reverse_delete_rule=CASCADE
-    )
-
-    @staticmethod
-    def get_all(is_cls):
-        """Returns all XSL exporters
-
-        Returns:
-            XSL exporter collection
-
-        """
-        if is_cls:
-            # will return all Template object only
-            return ExporterXsl.objects(
-                _cls="{0}.{1}".format(Exporter.__name__, ExporterXsl.__name__)
-            ).all()
-        else:
-            # will return all inherited object
-            return ExporterXsl.object().all()
-
-    @staticmethod
-    def get_all_by_xsl_id_list(xsl_id_list):
-        """Returns all Xsl exporter with the given id list
-
-        Returns:
-
-        """
-        return ExporterXsl.objects(xsl_transformation__in=xsl_id_list).all()
