@@ -6,7 +6,7 @@ from menu import Menu, MenuItem
 
 federated_children = (
     MenuItem(
-        "Exporter List", reverse("admin:core_exporters_app_exporters"), icon="list"
+        "Exporter List", reverse("core-admin:core_exporters_app_exporters"), icon="list"
     ),
 )
 
