@@ -1,41 +1,41 @@
 """ Exporter Serializers
 """
-from rest_framework.serializers import ListField
-from rest_framework_mongoengine.serializers import DocumentSerializer
+from rest_framework.serializers import ListField, ModelSerializer
 
+from core_main_app.commons.serializers import BasicSerializer
 import core_exporters_app.components.exporter.api as exporter_api
 import core_exporters_app.exporters.xsl.api as xsl_api
 from core_exporters_app.commons.constants import XSL_URL
 from core_exporters_app.components.exported_compressed_file.models import (
     ExportedCompressedFile,
 )
-from core_exporters_app.components.exporter.models import Exporter
-from core_exporters_app.exporters.xsl.models import ExporterXsl
-from core_main_app.commons.serializers import BasicSerializer
+from core_exporters_app.components.exporter.models import Exporter, ExporterXsl
 
 
-class ExporterSerializer(DocumentSerializer):
+class ExporterSerializer(ModelSerializer):
     """Exporter serializer"""
 
-    class Meta(object):
+    class Meta:
         """Meta"""
 
         model = Exporter
         fields = "__all__"
 
     def create(self, validated_data):
-        return exporter_api.upsert(Exporter(**validated_data))
+        exporter = exporter_api.upsert(Exporter(**validated_data))
+        return exporter
 
     def update(self, instance, validated_data):
         # The only field we can actually update is the name of the instance
         instance.name = validated_data.get("name", instance.name)
-        return exporter_api.upsert(instance)
+        exporter_api.upsert(instance)
+        return instance
 
 
-class ExporterXslSerializer(DocumentSerializer):
+class ExporterXslSerializer(ModelSerializer):
     """Xsl Exporter serializer"""
 
-    class Meta(object):
+    class Meta:
         """Meta"""
 
         model = ExporterXsl
@@ -47,7 +47,8 @@ class ExporterXslSerializer(DocumentSerializer):
         # set default values for XSL exporters
         exporter.enable_by_default = False
         exporter.url = XSL_URL
-        return xsl_api.upsert(exporter)
+        xsl_api.upsert(exporter)
+        return exporter
 
 
 class ExporterToZipSerializer(BasicSerializer):
@@ -57,10 +58,10 @@ class ExporterToZipSerializer(BasicSerializer):
     data_id_list = ListField(required=True)
 
 
-class ExporterExportedCompressedFileSerializer(DocumentSerializer):
+class ExporterExportedCompressedFileSerializer(ModelSerializer):
     """Compressed File serializer"""
 
-    class Meta(object):
+    class Meta:
         """Meta"""
 
         model = ExportedCompressedFile
