@@ -4,9 +4,9 @@ import logging
 
 from django.http.response import HttpResponse
 
-import core_exporters_app.components.exported_compressed_file.api as exported_file_api
 from core_main_app.commons import exceptions
 from core_main_app.utils.rendering import render
+import core_exporters_app.components.exported_compressed_file.api as exported_file_api
 
 logger = logging.getLogger(__name__)
 
@@ -33,10 +33,10 @@ def download_exported_compressed_file(request):
     try:
         # Get the exported file with the given id
         exported_file = exported_file_api.get_by_id(exporter_file_id, request.user)
-    except exceptions.DoesNotExist as e:
+    except exceptions.DoesNotExist:
         context["message"] = "The file with the given id does not exist."
-    except Exception as e:
-        logger.error("Something went wrong while downloading: {0}".format(str(e)))
+    except Exception as exception:
+        logger.error("Something went wrong while downloading: %s", str(exception))
         context[
             "message"
         ] = "Something went wrong while downloading. Please contact administrator"
@@ -47,23 +47,23 @@ def download_exported_compressed_file(request):
         response["Content-Disposition"] = (
             "attachment; filename=" + exported_file.file_name
         )
-        response["Content-Type"] = exported_file.file.content_type
+        response["Content-Type"] = exported_file.mime_type
         return response
-    else:
-        # Add assets
-        assets = {
-            "js": [
-                {
-                    "path": "core_exporters_app/user/js/exporter_compressed_file/download.js",
-                    "is_raw": False,
-                }
-            ],
-            "css": [],
-        }
-        # Render the page
-        return render(
-            request,
-            "core_exporters_app/user/exported_compressed_file/download.html",
-            context=context,
-            assets=assets,
-        )
+
+    # Add assets
+    assets = {
+        "js": [
+            {
+                "path": "core_exporters_app/user/js/exporter_compressed_file/download.js",
+                "is_raw": False,
+            }
+        ],
+        "css": [],
+    }
+    # Render the page
+    return render(
+        request,
+        "core_exporters_app/user/exported_compressed_file/download.html",
+        context=context,
+        assets=assets,
+    )
