@@ -1,8 +1,9 @@
 """ Fixture files for Exporters
 """
+from core_main_app.utils.integration_tests.fixture_interface import FixtureInterface
+
 import core_exporters_app.commons.constants as constants
 from core_exporters_app.components.exporter.models import Exporter
-from core_main_app.utils.integration_tests.fixture_interface import FixtureInterface
 
 
 class ExporterFixtures(FixtureInterface):
@@ -27,6 +28,9 @@ class ExporterFixtures(FixtureInterface):
 
         """
         self.data_1 = Exporter(
-            name="name_1", url=constants.XSL_URL, enable_by_default=False, templates=[]
-        ).save()
+            name="name_1",
+            url=constants.XSL_URL,
+            enable_by_default=False,
+        )
+        self.data_1.save()
         self.data_collection = [self.data_1]
