@@ -1,27 +1,30 @@
 """Integration tests for exporter rest api
 """
 
-from bson import ObjectId
 from rest_framework import status
 
-import core_exporters_app.rest.exporters.views as exporter_views
 from core_main_app.utils.integration_tests.integration_base_test_case import (
     MongoIntegrationBaseTestCase,
 )
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import RequestMock
+import core_exporters_app.rest.exporters.views as exporter_views
 from tests.rest.exporter.fixtures.fixtures import ExporterFixtures
 
 fixture_data = ExporterFixtures()
 
 
 class TestGetExportersList(MongoIntegrationBaseTestCase):
+    """Test Get Exporters List"""
+
     fixture = fixture_data
 
     def setUp(self):
-        super(TestGetExportersList, self).setUp()
+        """setUp"""
+        super().setUp()
 
     def test_get_all_returns_status_200_with_no_permission_needed(self):
+        """test_get_all_returns_status_200_with_no_permission_needed"""
         # Arrange
         user = create_mock_user("1")
 
@@ -35,13 +38,17 @@ class TestGetExportersList(MongoIntegrationBaseTestCase):
 
 
 class TestGetExportersDetail(MongoIntegrationBaseTestCase):
+    """Test Get Exporters Detail"""
+
     fixture = fixture_data
 
     def setUp(self):
-        super(TestGetExportersDetail, self).setUp()
+        """setUp"""
+        super().setUp()
         self.data = None
 
     def test_get_returns_object_when_found(self):
+        """test_get_returns_object_when_found"""
         # Arrange
         user = create_mock_user("0")
         self.param = {"pk": self.fixture.data_1.id}
@@ -55,9 +62,10 @@ class TestGetExportersDetail(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_get_raise_404_when_not_found(self):
+        """test_get_raise_404_when_not_found"""
         # Arrange
         user = create_mock_user("0")
-        self.param = {"pk": str(ObjectId())}
+        self.param = {"pk": -1}
 
         # Act
         response = RequestMock.do_request_get(
@@ -67,10 +75,11 @@ class TestGetExportersDetail(MongoIntegrationBaseTestCase):
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-    def test_get_raise_500_sever_error_when_general_error_occured(self):
+    def test_get_raise_500_sever_error_when_general_error_occurred(self):
+        """test_get_raise_500_sever_error_when_general_error_occurred"""
         # Arrange
         user = create_mock_user("0")
-        self.param = {"pk": "0"}
+        self.param = {"pk": "test"}
 
         # Act
         response = RequestMock.do_request_get(
@@ -82,16 +91,20 @@ class TestGetExportersDetail(MongoIntegrationBaseTestCase):
 
 
 class TestGetExporterDownload(MongoIntegrationBaseTestCase):
+    """Test Get Exporter Download"""
+
     fixture = fixture_data
 
     def setUp(self):
-        super(TestGetExporterDownload, self).setUp()
+        """setUp"""
+        super().setUp()
         self.data = None
 
     def test_get_raise_404_when_not_found(self):
+        """test_get_raise_404_when_not_found"""
         # Arrange
         user = create_mock_user("0")
-        self.param = {"pk": str(ObjectId())}
+        self.param = {"pk": -1}
 
         # Act
         response = RequestMock.do_request_get(
@@ -101,10 +114,11 @@ class TestGetExporterDownload(MongoIntegrationBaseTestCase):
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-    def test_get_raise_500_sever_error_when_general_error_occured(self):
+    def test_get_raise_500_sever_error_when_general_error_occurred(self):
+        """test_get_raise_500_sever_error_when_general_error_occurred"""
         # Arrange
         user = create_mock_user("0")
-        self.param = {"pk": "0"}
+        self.param = {"pk": "test"}
 
         # Act
         response = RequestMock.do_request_get(
