@@ -1,12 +1,16 @@
 """ Authentication tests for Exporters REST API
 """
+from django.core.files.uploadedfile import SimpleUploadedFile
 from django.test import SimpleTestCase
 from mock.mock import patch
 from rest_framework import status
 
+from core_main_app.utils.tests_tools.MockUser import create_mock_user
+from core_main_app.utils.tests_tools.RequestMock import RequestMock
+import core_main_app.components.data.api as data_api
+
 import core_exporters_app.components.exported_compressed_file.api as exported_compressed_file_api
 import core_exporters_app.components.exporter.api as exporter_api
-import core_main_app.components.data.api as data_api
 from core_exporters_app.components.exported_compressed_file.models import (
     ExportedCompressedFile,
 )
@@ -16,12 +20,14 @@ from core_exporters_app.rest.exporters.serializers import (
     ExporterSerializer,
     ExporterToZipSerializer,
 )
-from core_main_app.utils.tests_tools.MockUser import create_mock_user
-from core_main_app.utils.tests_tools.RequestMock import RequestMock
 
 
 class TestExporterListGetPermissions(SimpleTestCase):
+    """Test Exporter List Get Permissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             exporters_api_views.ExporterList.as_view(), None
         )
@@ -33,6 +39,8 @@ class TestExporterListGetPermissions(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, mock_exporter_serializer_data, mock_exporter_get_all
     ):
+        """test_authenticated_returns_http_200"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -46,6 +54,8 @@ class TestExporterListGetPermissions(SimpleTestCase):
     def test_staff_returns_http_200(
         self, mock_exporter_serializer_data, mock_exporter_get_all
     ):
+        """test_staff_returns_http_200"""
+
         mock_user = create_mock_user("1", is_staff=True)
 
         response = RequestMock.do_request_get(
@@ -56,7 +66,11 @@ class TestExporterListGetPermissions(SimpleTestCase):
 
 
 class TestExporterDetailGetPermissions(SimpleTestCase):
+    """Test Exporter Detail Get Permissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             exporters_api_views.ExporterDetail.as_view(), None
         )
@@ -68,6 +82,8 @@ class TestExporterDetailGetPermissions(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, mock_exporter_serializer_data, mock_exporter_get_by_id
     ):
+        """test_authenticated_returns_http_200"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -81,6 +97,8 @@ class TestExporterDetailGetPermissions(SimpleTestCase):
     def test_staff_returns_http_200(
         self, mock_exporter_serializer_data, mock_exporter_get_by_id
     ):
+        """test_staff_returns_http_200"""
+
         mock_user = create_mock_user("1", is_staff=True)
 
         response = RequestMock.do_request_get(
@@ -91,7 +109,11 @@ class TestExporterDetailGetPermissions(SimpleTestCase):
 
 
 class TestExportToZipPostPermissions(SimpleTestCase):
+    """Test Exporter To Zip Post Permissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_post(
             exporters_api_views.ExportToZip.as_view(), None
         )
@@ -111,6 +133,8 @@ class TestExportToZipPostPermissions(SimpleTestCase):
         mock_exporter_exporter_is_valid,
         mock_exporter_exporter_data,
     ):
+        """test_authenticated_returns_http_200"""
+
         mock_data_get_by_id_list.return_value = None
         mock_user = create_mock_user("1")
 
@@ -135,6 +159,8 @@ class TestExportToZipPostPermissions(SimpleTestCase):
         mock_exporter_exporter_is_valid,
         mock_exporter_exporter_data,
     ):
+        """test_staff_returns_http_200"""
+
         mock_data_get_by_id_list.return_value = None
         mock_user = create_mock_user("1", is_staff=True)
 
@@ -148,7 +174,11 @@ class TestExportToZipPostPermissions(SimpleTestCase):
 
 
 class TestExporterDownloadGetPermissions(SimpleTestCase):
+    """Test Exporter Download Get Permissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             exporters_api_views.ExporterDownload.as_view(), None
         )
@@ -159,10 +189,15 @@ class TestExporterDownloadGetPermissions(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, mock_exported_compressed_file_get_by_id
     ):
+        """test_authenticated_returns_http_200"""
+
         mock_user = create_mock_user("1")
 
         mock_exported_compressed_file_get_by_id.return_value = ExportedCompressedFile(
-            is_ready=True, file=None, file_name="", user_id=mock_user.id
+            is_ready=True,
+            file=SimpleUploadedFile("file.txt", b"file"),
+            file_name="",
+            user_id=mock_user.id,
         )
 
         response = RequestMock.do_request_get(
@@ -173,10 +208,15 @@ class TestExporterDownloadGetPermissions(SimpleTestCase):
 
     @patch.object(exported_compressed_file_api, "get_by_id")
     def test_staff_returns_http_200(self, mock_exported_compressed_file_get_by_id):
+        """test_staff_returns_http_200"""
+
         mock_user = create_mock_user("1", is_staff=True)
 
         mock_exported_compressed_file_get_by_id.return_value = ExportedCompressedFile(
-            is_ready=True, file=None, file_name="", user_id=mock_user.id
+            is_ready=True,
+            file=SimpleUploadedFile("file.txt", b"file"),
+            file_name="",
+            user_id=mock_user.id,
         )
 
         response = RequestMock.do_request_get(
