@@ -4,16 +4,21 @@ from django.test import SimpleTestCase
 from mock.mock import patch
 from rest_framework import status
 
+from core_main_app.utils.tests_tools.MockUser import create_mock_user
+from core_main_app.utils.tests_tools.RequestMock import RequestMock
+
 import core_exporters_app.components.exporter.api as exporter_api
 import core_exporters_app.exporters.xsl.api as xsl_api
 from core_exporters_app.rest.exporters.serializers import ExporterXslSerializer
 from core_exporters_app.rest.exporters.xsl import views as xsl_exporters_api_views
-from core_main_app.utils.tests_tools.MockUser import create_mock_user
-from core_main_app.utils.tests_tools.RequestMock import RequestMock
 
 
 class TestExporterXslListGetPermissions(SimpleTestCase):
+    """Test Exporter Xsl List Get Permissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             xsl_exporters_api_views.ExporterXslList.as_view(), None
         )
@@ -25,6 +30,8 @@ class TestExporterXslListGetPermissions(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, mock_exporter_serializer_data, mock_xsl_get_all
     ):
+        """test_authenticated_returns_http_200"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -38,6 +45,8 @@ class TestExporterXslListGetPermissions(SimpleTestCase):
     def test_staff_returns_http_200(
         self, mock_exporter_serializer_data, mock_xsl_get_all
     ):
+        """test_staff_returns_http_200"""
+
         mock_user = create_mock_user("1", is_staff=True)
 
         response = RequestMock.do_request_get(
@@ -48,7 +57,11 @@ class TestExporterXslListGetPermissions(SimpleTestCase):
 
 
 class TestExporterXslListPostPermissions(SimpleTestCase):
+    """Test Exporter Xsl List Post Permissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_post(
             xsl_exporters_api_views.ExporterXslList.as_view(), None
         )
@@ -61,6 +74,8 @@ class TestExporterXslListPostPermissions(SimpleTestCase):
     def test_authenticated_returns_http_403(
         self, mock_exporter_xsl_data, mock_exporter_xsl_save, mock_exporter_xsl_is_valid
     ):
+        """test_authenticated_returns_http_403"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_post(
@@ -75,6 +90,8 @@ class TestExporterXslListPostPermissions(SimpleTestCase):
     def test_staff_returns_http_201(
         self, mock_exporter_xsl_data, mock_exporter_xsl_save, mock_exporter_xsl_is_valid
     ):
+        """test_staff_returns_http_201"""
+
         mock_user = create_mock_user("1", is_staff=True)
 
         response = RequestMock.do_request_post(
@@ -85,7 +102,11 @@ class TestExporterXslListPostPermissions(SimpleTestCase):
 
 
 class TestExporterXslDetailGetPermissions(SimpleTestCase):
+    """Test Exporter Xsl Detail Get Permissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             xsl_exporters_api_views.ExporterXslDetail.as_view(), None
         )
@@ -97,6 +118,8 @@ class TestExporterXslDetailGetPermissions(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, mock_exporter_data, mock_exporter_get_by_id
     ):
+        """test_authenticated_returns_http_200"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -110,6 +133,7 @@ class TestExporterXslDetailGetPermissions(SimpleTestCase):
     @patch.object(exporter_api, "get_by_id")
     @patch.object(ExporterXslSerializer, "data")
     def test_staff_returns_http_200(self, mock_exporter_data, mock_exporter_get_by_id):
+        """test_staff_returns_http_200"""
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
